@@ -1,9 +1,9 @@
 use 5.008001;
 use strict;
 use warnings;
-package Email::MIME 1.951;
+package Email::MIME;
 # ABSTRACT: easy MIME message handling
-
+$Email::MIME::VERSION = '1.952';
 use Email::Simple 2.212; # nth header value
 use parent qw(Email::Simple);
 
@@ -940,7 +940,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.951
+version 1.952
 
 =head1 SYNOPSIS
 
