@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Email::MIME::Encode 1.951;
+package Email::MIME::Encode;
 # ABSTRACT: a private helper for MIME header encoding
-
+$Email::MIME::Encode::VERSION = '1.952';
 use Carp ();
 use Encode ();
 use Email::MIME::Header;
@@ -180,7 +180,7 @@ Email::MIME::Encode - a private helper for MIME header encoding
 
 =head1 VERSION
 
-version 1.951
+version 1.952
 
 =head1 PERL VERSION
 
