@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Email::MIME::Modifier 1.951;
+package Email::MIME::Modifier;
 # ABSTRACT: obsolete do-nothing library
-
+$Email::MIME::Modifier::VERSION = '1.952';
 1;
 
 __END__
@@ -17,7 +17,7 @@ Email::MIME::Modifier - obsolete do-nothing library
 
 =head1 VERSION
 
-version 1.951
+version 1.952
 
 =head1 PERL VERSION
 
